@@ -54,10 +54,14 @@ sub dump {
     make_path($workdir) unless -d $workdir;
 
     my $enc = Encode::Guess->guess($text);
-    ref($enc) or croak "无法猜测编码: $enc";
-    eval { $text = $enc->decode($text); };
-    if (!!$@) {
-      warn("字符串($text)解码失败：$@") if $self->debug == 0;
+    if (ref $enc) {
+      eval { $text = $enc->decode($text); };
+      if (!!$@) {
+        warn("[dump] 字符串解码失败：$@");
+      }
+    }
+    else {
+      warn("[dump] 无法猜测编码: $enc");
     }
 
     my $filename = "$workdir/$self->{device}{host}.txt";
@@ -77,14 +81,19 @@ sub write_file {
   make_path($workdir) unless -d $workdir;
 
   my $enc = Encode::Guess->guess($config);
-  ref($enc) or croak "无法猜测编码: $enc";
-  eval { $config = $enc->decode($config); };
-  if (!!$@) {
-    warn("字符串($config)解码失败：$@") if $self->debug == 0;
+  if (ref($enc)) {
+    eval { $config = $enc->decode($config); };
+    if (!!$@) {
+      $self->dump("[write_file] $name 字符串解码失败：$@");
+    }
+  }
+  else {
+    $self->dump("[write_file] $name 无法猜测编码: $enc");
   }
-  $self->dump("准备将配置文件写入工作目录: ($workdir)");
 
   my $filename = "$workdir/$name";
+  $self->dump("[write_file] 准备将数据写入本地文件: ($workdir/$name)");
+
   open(my $fh, '>>encoding(UTF-8)', $filename) or croak "无法打开文件 $filename 进行写入: $!";
   print $fh $config                            or croak "写入文件 $filename 失败: $!";
   close($fh)                                   or croak "关闭文件句柄 $filename 失败: $!";
@@ -130,3 +139,4 @@ sub refine_if {
 1;
 
 # ABSTRACT: Based Moose for network device discovery and management
+
